@@ -322,7 +322,7 @@ def inject_signal(array,t0,f_obs,f_sampling,A,phase):
     f = f_obs[thread_global_id][0]
 
     #compute GPS time
-    time = t0+(thread_global_id*f_sampling)
+    time = t0+(thread_global_id*(1/f_sampling))
 
     #inject in the real signal sinusoidal value
     array[thread_global_id]+= (A*math.sin(2*math.pi*f*time +phase))
@@ -339,7 +339,7 @@ def make_injection(signal, f_src, amplitude, src_pos, name, detector="H", delay=
     f_sampling = signal.sample_rate.value # hz
     duration   = signal.times[-1]-signal.times[0] #sec
     nb_measure = duration*(1/f_sampling)
-    t_0        = signal.t0.value
+    t_0        = signal.times[0].value
 
     t1=signal.times[0].value
     t2=signal.times[-1].value
